@@ -1,8 +1,9 @@
 from path import path
-import filecmp
 from tempfile import NamedTemporaryFile
 import os
+from filecmp import _sig, cmp as same_file
 
+# the mark that is used to identify stored originals that have been modified
 MARK = '!'
 
 def make_path(p, sep='_'):
@@ -11,13 +12,10 @@ def make_path(p, sep='_'):
     name, ext = p.splitext()
     n = 1
     while p.exists():
-        p = path(name + '%s%s%s' % (sep, n, ext))
+        p = path('%s%s%s%s' % (name, sep, n, ext))
         n += 1
     return p
 
-def same_file(p, pp):
-    return filecmp.cmp(p, pp)
-
 def mktemp():
     f = NamedTemporaryFile(delete=False)
     f.close()
@@ -25,11 +23,12 @@ def mktemp():
     loc.remove()
     return loc
 
-def filesig(pth):
+def file_sig(pth):
     '''
-    a signature of the file, if this remains the same we can be pretty sure that the file hasn't been changed
+    a signature of the file,
+    if this remains the same we can be pretty sure that the file hasn't been changed
     '''
-    return filecmp._sig(os.stat(pth))
+    return _sig(os.stat(pth))
 
 def dump(store):
     '''for debugging purposes'''
@@ -37,3 +36,7 @@ def dump(store):
     for p in (store.originals, store.storedat, store.ignored):
         pprint(p)
 
+def callable_or_value(obj):
+    if callable(obj):
+        return obj()
+    return obj
